import _debug from 'debug';
import fileEntryCache from 'file-entry-cache';
const debug = _debug('elint:cache');
class ElintCache {
    cacheFilePath;
    fileEntryCache;
    constructor(cacheFilePath) {
        this.cacheFilePath = cacheFilePath;
        debug(`Initial cache in ${cacheFilePath}`);
        this.fileEntryCache = fileEntryCache.create(cacheFilePath);
    }
    static getPresetString(internalLoadedPresetAndPlugins) {
        return `${internalLoadedPresetAndPlugins.internalPreset.name}@${internalLoadedPresetAndPlugins.internalPreset.version}`;
    }
    getFileCache(filePath, { internalLoadedPresetAndPlugins }) {
        const fileDescriptor = this.fileEntryCache.getFileDescriptor(filePath);
        if (fileDescriptor.notFound) {
            debug(`File not found: ${filePath}`);
            return false;
        }
        if (fileDescriptor.changed) {
            debug(`File changed: ${filePath}`);
            return false;
        }
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        const cachePresetString = fileDescriptor
            .meta?.presetString;
        /* istanbul ignore next */
        if (!cachePresetString) {
            debug(`Cache missed: ${filePath}`);
            return false;
        }
        if (cachePresetString !==
            ElintCache.getPresetString(internalLoadedPresetAndPlugins)) {
            debug(`Preset changed: ${filePath}`);
            return false;
        }
        debug(`Skipping file since it hasn't changed: ${filePath}`);
        return true;
    }
    setFileCache(result, { fix, internalLoadedPresetAndPlugins, write }) {
        const filePath = result.filePath;
        /* istanbul ignore next */
        if (!filePath) {
            return;
        }
        const fileDescriptor = this.fileEntryCache.getFileDescriptor(filePath);
        if (!fileDescriptor.notFound) {
            let success = !result.errorCount && !result.warningCount;
            // fix 且不写入文件时的结果不缓存
            if (fix && !write) {
                success = false;
            }
            if (!success) {
                this.fileEntryCache.removeEntry(filePath);
                debug(`Removing cache result: ${filePath}`);
                return;
            }
            debug(`Updating cache result: ${filePath}`);
            const cachePresetString = ElintCache.getPresetString(internalLoadedPresetAndPlugins);
            fileDescriptor.meta.presetString = cachePresetString;
        }
    }
    reconcile() {
        debug(`Cache saved to ${this.cacheFilePath}`);
        this.fileEntryCache.reconcile();
    }
    delete() {
        debug('Cache deleted.');
        this.fileEntryCache.deleteCacheFile();
    }
}
export default ElintCache;
//# sourceMappingURL=elint-cache.js.map