import _debug from 'debug';
import { execa } from 'execa';
import detectPackageManager from './detect-package-manager.js';
const debug = _debug('elint:notifier:getPackageInfo');
const PACKAGE_MANAGER_INFO_COMMAND = {
    npm: 'npm info {} --json',
    pnpm: 'pnpm info {} --json',
    yarn: 'yarn info {} --json',
    'yarn@berry': 'yarn npm info {} --json'
};
async function getPackageInfo(packageName, cwd) {
    const packageManager = await detectPackageManager(cwd);
    debug(`current package manager: ${packageManager}`);
    if (!packageManager) {
        return null;
    }
    try {
        const commands = PACKAGE_MANAGER_INFO_COMMAND[packageManager]
            .replace('{}', packageName)
            .split(' ');
        const getPackageInfoProcess = execa(commands[0], commands.slice(1), {
            cwd
        });
        const { stdout } = await Promise.race([
            getPackageInfoProcess,
            // 当 registry 无法连接时，npm 和 pnpm 会长时间挂起
            new Promise((resolve, reject) => {
                setTimeout(() => {
                    getPackageInfoProcess.cancel();
                    reject(new Error('timeout'));
                }, 3000);
            })
        ]);
        let info = JSON.parse(stdout);
        if (packageManager === 'yarn') {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            info = info.data;
        }
        if (!info || info.name !== packageName) {
            throw new Error(`Command '${commands.join(' ')}' didn't response with a valid package info`);
        }
        debug('get package info: %o', info);
        return info;
    }
    catch (e) {
        debug('get package info error: %o', e);
        return null;
    }
}
export default getPackageInfo;
//# sourceMappingURL=get-package-info.js.map