import { pathToFileURL } from 'url';
import { createRequire } from 'module';
import path from 'path';
import _debug from 'debug';
import resolvePackagePath from 'resolve-package-path';
import { cloneDeep } from 'lodash-es';
import { isElintPlugin } from './types.js';
const debug = _debug('elint:plugin:load');
const loadElintPlugin = async (plugin, { cwd, presetPath }) => {
    if (typeof plugin === 'string') {
        debug(`start load plugin: ${plugin}`);
        const require = createRequire(path.join(presetPath || cwd, '__placeholder__.js'));
        const pluginPath = require.resolve(plugin);
        const pluginModule = await import(pathToFileURL(pluginPath).toString());
        let pluginPackagePath;
        try {
            const pluginPackageJsonPath = resolvePackagePath(plugin, presetPath || cwd);
            if (pluginPackageJsonPath) {
                pluginPackagePath = path.dirname(pluginPackageJsonPath);
            }
        }
        catch {
            /* istanbul ignore next */
            debug(`Plugin ${plugin} doesn't have a package.json`);
        }
        /* istanbul ignore next */
        const pluginConfig = pluginModule.default || pluginModule;
        if (!isElintPlugin(pluginConfig) || pluginConfig.name !== plugin) {
            throw new Error(`'${plugin}' is not an available elint plugin`);
        }
        debug(`loaded plugin: ${plugin}`);
        return {
            name: pluginConfig.name,
            path: pluginPackagePath,
            plugin: cloneDeep(pluginConfig)
        };
    }
    if (isElintPlugin(plugin)) {
        debug(`loaded custom plugin: ${plugin.name}`);
        return {
            name: plugin.name,
            plugin: cloneDeep(plugin)
        };
    }
    /* istanbul ignore next */
    throw new Error('Unknown elint plugin');
};
export const loadElintPlugins = async (plugins, ctx) => {
    debug('start load elint plugins');
    const internalPlugins = await Promise.all(plugins.map((plugin) => loadElintPlugin(plugin, ctx)));
    debug('loaded elint plugins: %o', internalPlugins.map((internalPlugin) => internalPlugin.name));
    return internalPlugins;
};
//# sourceMappingURL=load.js.map